
# Slot: type




URI: [ks:FamilialRelationship_type](https://w3id.org/linkml/tests/kitchen_sink/FamilialRelationship_type)


## Domain and Range

[FamilialRelationship](FamilialRelationship.md) &#8594;  <sub>1..1</sub> [FamilialRelationshipType](FamilialRelationshipType.md)

## Parents

 *  is_a: [type](type.md)

## Children


## Used by

 * [FamilialRelationship](FamilialRelationship.md)
